@@ -493,7 +493,7 @@ class Get_App_Appinfo(Qimai_Diy_Var):
 
     def get_appinfo(self):
         """
-            * 获取App的基本信息；
+            * 获取App的基本信息(无关联推荐版本信息)；
         """
         url = 'https://api.qimai.cn/app/appinfo?appid=%s&country=%s' %(self.appid, self.country)
         res = session.get(url, headers=headers)
@@ -529,6 +529,25 @@ class Get_App_Appinfo(Qimai_Diy_Var):
         self.purchases_num = self.appinfo['appInfo']['purchases_num']
         return self.purchases_num
 
+    def get_baseinfo(self):
+        """
+            * 获取App基础信息(包含开发商名称内购价格、关联推荐产品)
+        """
+        url = 'https://api.qimai.cn/app/baseinfo?country=%s&appid=%s' %(self.country, self.appid)
+        res = session.get(url, headers=headers)
+        self.app_baseinfo_data = res.json()
+        return self.app_baseinfo_data
+
+    def get_version(self, start_date='', end_date=''):
+        """
+            * 获取App的版本信息：
+            * 可设定时间段，默认全部；
+        """
+        url = 'https://api.qimai.cn/app/version?country=%s&appid=%s&sdate=%s&edate=%s' %(self.country, self.appid, start_date, end_date)
+        res = session.get(url, headers=headers)
+        self.app_version_data = res.json()
+        return self.app_version_data
+
 # 获取榜单相关数据；
 class Get_App_Rank(Qimai_Diy_Var):
     """
@@ -549,34 +568,34 @@ class Get_App_Rank(Qimai_Diy_Var):
         self.simple = simple
         self.rankEchartType = rankEchartType
 
-    def get_rank_info(self):
+    def get_rank_data(self):
         """
             * 获取App的榜单数据：
         """
         url = 'https://api.qimai.cn/app/rankMore?appid=%s&country=%s&brand=%s&day=%s&appRankShow=%s&subclass=%s&simple=%s&sdate=%s&edate=%s&rankEchartType=%s&rankType=%s&device=%s' %(self.appid, self.country, self.brand, self.day, self.appRankShow, self.subclass, self.simple, self.start_date, self.end_date, self.rankEchartType, self.rankType, self.device)
         res = session.get(url, headers=headers)
-        self.rank_info = res.json()
-        return self.rank_info
+        self.rank_data = res.json()
+        return self.rank_data
 
-    def all_rank(self):
+    def get_all_rank_data(self):
         """
             * 获取所有榜单的数据列表；
             从json中获取并返回，可能为空；
         """
-        self.get_rank_info()
+        self.get_rank_data()
         try:
-            return self.rank_info['data']['list']
+            return self.rank_data['data']['list']
         except:
             return []
 
-    def clear_rank(self):
+    def get_clear_rank_data(self):
         """
             * 获取清榜数据；
             从json中获取并返回，可能为空；
         """
-        self.get_rank_info()
+        self.get_rank_data()
         try:
-            return self.rank_info['data']['clear']
+            return self.rank_data['data']['clear']
         except:
             return []
 
@@ -685,7 +704,8 @@ class Get_Keyword_Info(Qimai_Diy_Var):
             * 获取关键词下关键词相关信息:
             * 包含指数、结果数、WordID等；
         """
-        url = 'https://api.qimai.cn/search/getWordInfo?device=%s&country=%s&search=%s&version=%s&date=%s&search_type=%s&edate=%s&status=%s' %(self.device, self.country, self.keyword, self.version, self.start_date, self.search_type, self.end_date, self.status)
+        url = 'https://api.qimai.cn/search/getWordInfo?device=%s&country=%s&search=%s&version=%s&date=%s&search_type=%s&status=%s' %(self.device, self.country, self.keyword, self.version, self.start_date, self.search_type, self.status)
+        # url = 'https://api.qimai.cn/search/getWordInfo?device=%s&country=%s&search=%s&version=%s&date=%s&search_type=%s&edate=%s&status=%s' %(self.device, self.country, self.keyword, self.version, self.start_date, self.search_type, self.end_date, self.status)
         headers = {
             'origin': 'https://www.qimai.cn',
             'referer': 'https://www.qimai.cn/',
@@ -713,7 +733,7 @@ class Get_Keyword_Info(Qimai_Diy_Var):
 
     def get_hotSearch_data(self):
         """
-            * 获取关键词热搜相关数据；
+            * 获取关键词热搜相关数据-默认90天内全部数据；
         """
         url = 'https://api.qimai.cn/engagement/historySearch?country=%s&version=%s&search_type=1&search=%s' %(self.country, self.version, self.keyword)
         res = session.get(url, headers=headers)
@@ -1460,7 +1480,7 @@ class Get_Keyword_LoseNewDownUp_List(Get_Clear_Keyword_List):
         """
              * 获取词下排名上升较快App的数据-第一页：
         """
-        url = 'https://api.qimai.cn/search/searchPageExtend?history=%s&version=%s&device=%s&filter=%s&word=%s&country=%s&date=oneMonth&sort=up_rank&sort_type=%s&type=up&sdate=%s&edate=%s&page=%s' % (self.top_history, self.version, self.device, self.filter, self.keyword, self.country, self.sort_type, self.start_date, self.end_date, page_num)
+        url = 'https://api.qimai.cn/search/searchPageExtend?history=%s&version=%s&device=%s&filter=%s&word=%s&country=%s&date=oneMonth&sort=up_rank&sort_type=%s&type=up&sdate=%s&edate=%s&page=1' % (self.top_history, self.version, self.device, self.filter, self.keyword, self.country, self.sort_type, self.start_date, self.end_date)
         res = session.get(url, headers=headers)
         self.rankGoUp_onePage_data = res.json()
         return self.rankGoUp_onePage_data
